@@ -24,7 +24,7 @@
 
 #include "mdadm.h"
 
-char Version[] = Name " - v2.6.3 - 20th August 2007\n";
+char Version[] = Name " - v2.6.5 - 15th May 2008\n";
 
 /*
  * File: ReadMe.c
@@ -110,7 +110,7 @@ struct option long_options[] = {
 
     /* synonyms */
     {"monitor",   0, 0, 'F'},
-	    
+
     /* after those will normally come the name of the md device */
     {"help",      0, 0, 'h'},
     {"help-options",0,0,'h'},
@@ -592,7 +592,7 @@ mapping_t r5layout[] = {
 };
 
 mapping_t pers[] = {
-	{ "linear", -1},
+	{ "linear", LEVEL_LINEAR},
 	{ "raid0", 0},
 	{ "0", 0},
 	{ "stripe", 0},
@@ -603,13 +603,13 @@ mapping_t pers[] = {
 	{ "4", 4},
 	{ "raid5", 5},
 	{ "5", 5},
-	{ "multipath", -4},
-	{ "mp", -4},
+	{ "multipath", LEVEL_MULTIPATH},
+	{ "mp", LEVEL_MULTIPATH},
 	{ "raid6", 6},
 	{ "6", 6},
 	{ "raid10", 10},
 	{ "10", 10},
-	{ "faulty", -5},
+	{ "faulty", LEVEL_FAULTY},
 	{ NULL, 0}
 };
 
